pub struct ExampleScenarioProcessStep {
pub id: Option<String>,
pub extension: Vec<Extension>,
pub modifier_extension: Vec<Extension>,
pub process: Vec<ExampleScenarioProcess>,
pub pause: Option<Boolean>,
pub operation: Option<ExampleScenarioProcessStepOperation>,
pub alternative: Vec<ExampleScenarioProcessStepAlternative>,
}Expand description
Each step of the process.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
modifier_extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
process: Vec<ExampleScenarioProcess>Nested process.
pause: Option<Boolean>If there is a pause in the flow.
operation: Option<ExampleScenarioProcessStepOperation>Each interaction or action.
alternative: Vec<ExampleScenarioProcessStepAlternative>Indicates an alternative step that can be taken instead of the operations on the base step in exceptional/atypical circumstances.