pub struct SpecimenDefinitionTypeTestedContainer {
pub id: Option<String>,
pub extension: Vec<Extension>,
pub modifier_extension: Vec<Extension>,
pub material: Option<Box<CodeableConcept>>,
pub type: Option<Box<CodeableConcept>>,
pub cap: Option<Box<CodeableConcept>>,
pub description: Option<String>,
pub capacity: Option<Box<Quantity>>,
pub minimum_volume: Option<SpecimenDefinitionTypeTestedContainerMinimumVolume>,
pub additive: Vec<SpecimenDefinitionTypeTestedContainerAdditive>,
pub preparation: Option<String>,
}Expand description
The specimen’s container.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
modifier_extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
material: Option<Box<CodeableConcept>>The type of material of the container.
type: Option<Box<CodeableConcept>>The type of container used to contain this kind of specimen.
cap: Option<Box<CodeableConcept>>Color of container cap.
description: Option<String>The textual description of the kind of container.
capacity: Option<Box<Quantity>>The capacity (volume or other measure) of this kind of container.
minimum_volume: Option<SpecimenDefinitionTypeTestedContainerMinimumVolume>The minimum volume to be conditioned in the container.
additive: Vec<SpecimenDefinitionTypeTestedContainerAdditive>Substance introduced in the kind of container to preserve, maintain or enhance the specimen. Examples: Formalin, Citrate, EDTA.
preparation: Option<String>Special processing that should be applied to the container for this kind of specimen.