pub struct ValueSetComposeIncludeConcept {
pub id: Option<String>,
pub extension: Vec<Extension>,
pub modifier_extension: Vec<Extension>,
pub code: Code,
pub display: Option<String>,
pub designation: Vec<ValueSetComposeIncludeConceptDesignation>,
}Expand description
Specifies a concept to be included or excluded.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
modifier_extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
code: CodeSpecifies a code for the concept to be included or excluded.
display: Option<String>The text to display to the user for this concept in the context of this valueset. If no display is provided, then applications using the value set use the display specified for the code by the system.
designation: Vec<ValueSetComposeIncludeConceptDesignation>Additional representations for this concept when used in this value set - other languages, aliases, specialized purposes, used for particular purposes, etc.