pub struct SubscriptionTopicResourceTriggerQueryCriteria {
pub id: Option<String>,
pub extension: Vec<Extension>,
pub modifier_extension: Vec<Extension>,
pub previous: Option<String>,
pub result_for_create: Option<Code>,
pub current: Option<String>,
pub result_for_delete: Option<Code>,
pub require_both: Option<Boolean>,
}Expand description
The FHIR query based rules that the server should use to determine when to trigger a notification for this subscription topic.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
modifier_extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
previous: Option<String>The FHIR query based rules are applied to the previous resource state (e.g., state before an update).
result_for_create: Option<Code>For create interactions, should the previous criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during create interactions is unspecified (server discretion).
current: Option<String>The FHIR query based rules are applied to the current resource state (e.g., state after an update).
result_for_delete: Option<Code>For ‘delete’ interactions, should the ‘current’ query criteria count as an automatic pass or an automatic fail. If not present, the testing behavior during delete interactions is unspecified (server discretion).
require_both: Option<Boolean>If set to true, both the current and previous query criteria must evaluate true to trigger a notification for this topic. If set to false or not present, a notification for this topic will be triggered if either the current or previous tests evaluate to true.