Enum ElementDefinitionExampleValue

pub enum ElementDefinitionExampleValue {
Show 55 variants Base64Binary(Base64Binary), Boolean(Boolean), Canonical(Canonical), Code(Code), Date(Date), DateTime(DateTime), Decimal(Decimal), Id(Id), Instant(Instant), Integer(Integer), Integer64(Integer64), Markdown(Markdown), Oid(Oid), PositiveInt(PositiveInt), String(String), Time(Time), UnsignedInt(UnsignedInt), Uri(Uri), Url(Url), Uuid(Uuid), Address(Box<Address>), Age(Box<Age>), Annotation(Box<Annotation>), Attachment(Box<Attachment>), CodeableConcept(Box<CodeableConcept>), CodeableReference(Box<CodeableReference>), Coding(Box<Coding>), ContactPoint(Box<ContactPoint>), Count(Box<Count>), Distance(Box<Distance>), Duration(Box<Duration>), HumanName(Box<HumanName>), Identifier(Box<Identifier>), Money(Box<Money>), Period(Box<Period>), Quantity(Box<Quantity>), Range(Box<Range>), Ratio(Box<Ratio>), RatioRange(Box<RatioRange>), Reference(Box<Reference>), SampledData(Box<SampledData>), Signature(Box<Signature>), Timing(Box<Timing>), ContactDetail(Box<ContactDetail>), DataRequirement(Box<DataRequirement>), Expression(Box<Expression>), ParameterDefinition(Box<ParameterDefinition>), RelatedArtifact(Box<RelatedArtifact>), TriggerDefinition(Box<TriggerDefinition>), UsageContext(Box<UsageContext>), Availability(Box<Availability>), ExtendedContactDetail(Box<ExtendedContactDetail>), Dosage(Box<Dosage>), Meta(Box<Meta>), Invalid,
}
The actual value for the element, which must be one of the types allowed for this element.

Variants



Base64Binary(Base64Binary)



Boolean(Boolean)



Canonical(Canonical)



Code(Code)



Date(Date)



DateTime(DateTime)



Decimal(Decimal)



Id(Id)



Instant(Instant)



Integer(Integer)



Integer64(Integer64)



Markdown(Markdown)



Oid(Oid)



PositiveInt(PositiveInt)



String(String)



Time(Time)



UnsignedInt(UnsignedInt)



Uri(Uri)



Url(Url)



Uuid(Uuid)



Address(Box<Address>)



Age(Box<Age>)



Annotation(Box<Annotation>)



Attachment(Box<Attachment>)



CodeableConcept(Box<CodeableConcept>)



CodeableReference(Box<CodeableReference>)



Coding(Box<Coding>)



ContactPoint(Box<ContactPoint>)



Count(Box<Count>)



Distance(Box<Distance>)



Duration(Box<Duration>)



HumanName(Box<HumanName>)



Identifier(Box<Identifier>)



Money(Box<Money>)



Period(Box<Period>)



Quantity(Box<Quantity>)



Range(Box<Range>)



Ratio(Box<Ratio>)



RatioRange(Box<RatioRange>)



Reference(Box<Reference>)



SampledData(Box<SampledData>)



Signature(Box<Signature>)



Timing(Box<Timing>)



ContactDetail(Box<ContactDetail>)



DataRequirement(Box<DataRequirement>)



Expression(Box<Expression>)



ParameterDefinition(Box<ParameterDefinition>)



RelatedArtifact(Box<RelatedArtifact>)



TriggerDefinition(Box<TriggerDefinition>)



UsageContext(Box<UsageContext>)



Availability(Box<Availability>)



ExtendedContactDetail(Box<ExtendedContactDetail>)



Dosage(Box<Dosage>)



Meta(Box<Meta>)



Invalid