pub struct Annotation {
pub id: Option<String>,
pub extension: Vec<Extension>,
pub author: Option<AnnotationAuthor>,
pub time: Option<DateTime>,
pub text: Markdown,
}Expand description
Annotation Type: A text note which also contains information about who made the statement and when.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
The individual responsible for making the annotation.
time: Option<DateTime>Indicates when this particular annotation was made.
text: MarkdownThe text of the annotation in markdown format.