pub struct ElementDefinitionType {
pub id: Option<String>,
pub extension: Vec<Extension>,
pub code: Uri,
pub profile: Vec<Canonical>,
pub target_profile: Vec<Canonical>,
pub aggregation: Vec<Code>,
pub versioning: Option<Code>,
}Expand description
The data type or resource that the value of this element is permitted to be.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
code: UriURL of Data type or Resource that is a(or the) type used for this element. References are URLs that are relative to http://hl7.org/fhir/StructureDefinition e.g. “string” is a reference to http://hl7.org/fhir/StructureDefinition/string. Absolute URLs are only allowed in logical models.
profile: Vec<Canonical>Identifies a profile structure or implementation Guide that applies to the datatype this element refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the type SHALL conform to at least one profile defined in the implementation guide.
target_profile: Vec<Canonical>Used when the type is “Reference” or “canonical”, and identifies a profile structure or implementation Guide that applies to the target of the reference this element refers to. If any profiles are specified, then the content must conform to at least one of them. The URL can be a local reference - to a contained StructureDefinition, or a reference to another StructureDefinition or Implementation Guide by a canonical URL. When an implementation guide is specified, the target resource SHALL conform to at least one profile defined in the implementation guide.
aggregation: Vec<Code>If the type is a reference to another resource, how the resource is or can be aggregated - is it a contained resource, or a reference, and if the context is a bundle, is it included in the bundle.
versioning: Option<Code>Whether this reference needs to be version specific or version independent, or whether either can be used.