pub struct CodeableConcept {
pub id: Option<String>,
pub extension: Vec<Extension>,
pub coding: Vec<Coding>,
pub text: Option<String>,
}Expand description
CodeableConcept Type: A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text.
This is a common pattern in healthcare - a concept that may be defined by one or more codes from formal definitions including LOINC and SNOMED CT, and/or defined by the provision of text that captures a human sense of the concept.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Vec<Extension>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
coding: Vec<Coding>A reference to a code defined by a terminology system.
text: Option<String>A human language representation of the concept as seen/selected/uttered by the user who entered the data and/or which represents the intended meaning of the user.